"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
from ..... import google_rpc
from ..... import neptune_pb
import typing
DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RequestStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class CodeByCount(google.protobuf.message.Message):
        """in case all operations are successful {"OK": 1}, otherwise errors are reported"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        CODE_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        DETAIL_FIELD_NUMBER: builtins.int
        code: google_rpc.code_pb2.Code.ValueType
        count: builtins.int
        detail: neptune_pb.ingest.v1.ingest_pb2.IngestCode.ValueType

        def __init__(self, *, code: google_rpc.code_pb2.Code.ValueType=..., count: builtins.int=..., detail: neptune_pb.ingest.v1.ingest_pb2.IngestCode.ValueType=...) -> None:
            ...

        def ClearField(self, field_name: typing.Literal['code', b'code', 'count', b'count', 'detail', b'detail']) -> None:
            ...
    CODE_BY_COUNT_FIELD_NUMBER: builtins.int
    SHARED_ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    shared_error_message: builtins.str
    'in case error spans all operations of request'

    @property
    def code_by_count(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RequestStatus.CodeByCount]:
        ...

    def __init__(self, *, code_by_count: collections.abc.Iterable[global___RequestStatus.CodeByCount] | None=..., shared_error_message: builtins.str | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_shared_error_message', b'_shared_error_message', 'shared_error_message', b'shared_error_message']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_shared_error_message', b'_shared_error_message', 'code_by_count', b'code_by_count', 'shared_error_message', b'shared_error_message']) -> None:
        ...

    def WhichOneof(self, oneof_group: typing.Literal['_shared_error_message', b'_shared_error_message']) -> typing.Literal['shared_error_message'] | None:
        ...
global___RequestStatus = RequestStatus