"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ProtoSeriesValuesResponseDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SERIES_FIELD_NUMBER: builtins.int

    @property
    def series(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProtoSeriesValuesSingleSeriesResponseDTO]:
        ...

    def __init__(self, *, series: collections.abc.Iterable[global___ProtoSeriesValuesSingleSeriesResponseDTO] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['series', b'series']) -> None:
        ...
global___ProtoSeriesValuesResponseDTO = ProtoSeriesValuesResponseDTO

@typing.final
class ProtoSeriesValuesSingleSeriesResponseDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REQUESTID_FIELD_NUMBER: builtins.int
    SEARCHAFTER_FIELD_NUMBER: builtins.int
    STRING_SERIES_FIELD_NUMBER: builtins.int
    SERIESVALUES_FIELD_NUMBER: builtins.int
    requestId: builtins.str

    @property
    def searchAfter(self) -> global___ProtoSeriesValuesSearchAfterDTO:
        ...

    @property
    def string_series(self) -> global___ProtoSeriesValuesDTO:
        """deprecated"""

    @property
    def seriesValues(self) -> global___ProtoSeriesValuesDTO:
        ...

    def __init__(self, *, requestId: builtins.str=..., searchAfter: global___ProtoSeriesValuesSearchAfterDTO | None=..., string_series: global___ProtoSeriesValuesDTO | None=..., seriesValues: global___ProtoSeriesValuesDTO | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_searchAfter', b'_searchAfter', 'searchAfter', b'searchAfter', 'series', b'series', 'seriesValues', b'seriesValues', 'string_series', b'string_series']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_searchAfter', b'_searchAfter', 'requestId', b'requestId', 'searchAfter', b'searchAfter', 'series', b'series', 'seriesValues', b'seriesValues', 'string_series', b'string_series']) -> None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_searchAfter', b'_searchAfter']) -> typing.Literal['searchAfter'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['series', b'series']) -> typing.Literal['string_series', 'seriesValues'] | None:
        ...
global___ProtoSeriesValuesSingleSeriesResponseDTO = ProtoSeriesValuesSingleSeriesResponseDTO

@typing.final
class ProtoSeriesValuesSearchAfterDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FINISHED_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    finished: builtins.bool
    token: builtins.str

    def __init__(self, *, finished: builtins.bool=..., token: builtins.str=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['finished', b'finished', 'token', b'token']) -> None:
        ...
global___ProtoSeriesValuesSearchAfterDTO = ProtoSeriesValuesSearchAfterDTO

@typing.final
class ProtoFloatSeriesValuesResponseDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SERIES_FIELD_NUMBER: builtins.int

    @property
    def series(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProtoFloatSeriesValuesSingleSeriesResponseDTO]:
        ...

    def __init__(self, *, series: collections.abc.Iterable[global___ProtoFloatSeriesValuesSingleSeriesResponseDTO] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['series', b'series']) -> None:
        ...
global___ProtoFloatSeriesValuesResponseDTO = ProtoFloatSeriesValuesResponseDTO

@typing.final
class ProtoFloatSeriesValuesSingleSeriesResponseDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REQUESTID_FIELD_NUMBER: builtins.int
    SERIES_FIELD_NUMBER: builtins.int
    requestId: builtins.str

    @property
    def series(self) -> global___ProtoFloatSeriesValuesDTO:
        ...

    def __init__(self, *, requestId: builtins.str=..., series: global___ProtoFloatSeriesValuesDTO | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['series', b'series']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['requestId', b'requestId', 'series', b'series']) -> None:
        ...
global___ProtoFloatSeriesValuesSingleSeriesResponseDTO = ProtoFloatSeriesValuesSingleSeriesResponseDTO

@typing.final
class ProtoFloatSeriesValuesDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOTAL_ITEM_COUNT_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    total_item_count: builtins.int

    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProtoFloatPointValueDTO]:
        ...

    def __init__(self, *, total_item_count: builtins.int=..., values: collections.abc.Iterable[global___ProtoFloatPointValueDTO] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['total_item_count', b'total_item_count', 'values', b'values']) -> None:
        ...
global___ProtoFloatSeriesValuesDTO = ProtoFloatSeriesValuesDTO

@typing.final
class ProtoFloatPointValueDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TIMESTAMP_MILLIS_FIELD_NUMBER: builtins.int
    STEP_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    COMPLETION_RATIO_FIELD_NUMBER: builtins.int
    timestamp_millis: builtins.int
    step: builtins.float
    value: builtins.float
    is_preview: builtins.bool
    completion_ratio: builtins.float

    def __init__(self, *, timestamp_millis: builtins.int=..., step: builtins.float=..., value: builtins.float=..., is_preview: builtins.bool=..., completion_ratio: builtins.float=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['completion_ratio', b'completion_ratio', 'is_preview', b'is_preview', 'step', b'step', 'timestamp_millis', b'timestamp_millis', 'value', b'value']) -> None:
        ...
global___ProtoFloatPointValueDTO = ProtoFloatPointValueDTO

@typing.final
class ProtoSeriesValuesDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALUES_FIELD_NUMBER: builtins.int

    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProtoPointValueDTO]:
        ...

    def __init__(self, *, values: collections.abc.Iterable[global___ProtoPointValueDTO] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['values', b'values']) -> None:
        ...
global___ProtoSeriesValuesDTO = ProtoSeriesValuesDTO

@typing.final
class ProtoPointValueDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TIMESTAMP_MILLIS_FIELD_NUMBER: builtins.int
    STEP_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    COMPLETION_RATIO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    timestamp_millis: builtins.int
    step: builtins.float
    value: builtins.str
    'deprecated'
    is_preview: builtins.bool
    completion_ratio: builtins.float

    @property
    def object(self) -> global___ProtoSeriesPointValueObjectDTO:
        ...

    def __init__(self, *, timestamp_millis: builtins.int=..., step: builtins.float=..., value: builtins.str | None=..., is_preview: builtins.bool=..., completion_ratio: builtins.float=..., object: global___ProtoSeriesPointValueObjectDTO | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_object', b'_object', '_value', b'_value', 'object', b'object', 'value', b'value']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_object', b'_object', '_value', b'_value', 'completion_ratio', b'completion_ratio', 'is_preview', b'is_preview', 'object', b'object', 'step', b'step', 'timestamp_millis', b'timestamp_millis', 'value', b'value']) -> None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_object', b'_object']) -> typing.Literal['object'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_value', b'_value']) -> typing.Literal['value'] | None:
        ...
global___ProtoPointValueDTO = ProtoPointValueDTO

@typing.final
class ProtoSeriesPointValueObjectDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STRINGVALUE_FIELD_NUMBER: builtins.int
    HISTOGRAM_FIELD_NUMBER: builtins.int
    FILEREF_FIELD_NUMBER: builtins.int
    stringValue: builtins.str

    @property
    def histogram(self) -> global___ProtoHistogram:
        ...

    @property
    def fileRef(self) -> global___ProtoFileRef:
        ...

    def __init__(self, *, stringValue: builtins.str=..., histogram: global___ProtoHistogram | None=..., fileRef: global___ProtoFileRef | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['fileRef', b'fileRef', 'histogram', b'histogram', 'stringValue', b'stringValue', 'value', b'value']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['fileRef', b'fileRef', 'histogram', b'histogram', 'stringValue', b'stringValue', 'value', b'value']) -> None:
        ...

    def WhichOneof(self, oneof_group: typing.Literal['value', b'value']) -> typing.Literal['stringValue', 'histogram', 'fileRef'] | None:
        ...
global___ProtoSeriesPointValueObjectDTO = ProtoSeriesPointValueObjectDTO

@typing.final
class ProtoHistogram(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    EDGES_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    type: builtins.str

    @property
    def edges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        ...

    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        ...

    def __init__(self, *, type: builtins.str=..., edges: collections.abc.Iterable[builtins.float] | None=..., values: collections.abc.Iterable[builtins.float] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['edges', b'edges', 'type', b'type', 'values', b'values']) -> None:
        ...
global___ProtoHistogram = ProtoHistogram

@typing.final
class ProtoFileRef(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PATH_FIELD_NUMBER: builtins.int
    SIZEBYTES_FIELD_NUMBER: builtins.int
    MIMETYPE_FIELD_NUMBER: builtins.int
    path: builtins.str
    sizeBytes: builtins.int
    mimeType: builtins.str

    def __init__(self, *, path: builtins.str=..., sizeBytes: builtins.int=..., mimeType: builtins.str=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['mimeType', b'mimeType', 'path', b'path', 'sizeBytes', b'sizeBytes']) -> None:
        ...
global___ProtoFileRef = ProtoFileRef

@typing.final
class ProtoTimeseriesBucketsDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ENTRIES_FIELD_NUMBER: builtins.int

    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TimeseriesBuckets]:
        ...

    def __init__(self, *, entries: collections.abc.Iterable[global___TimeseriesBuckets] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['entries', b'entries']) -> None:
        ...
global___ProtoTimeseriesBucketsDTO = ProtoTimeseriesBucketsDTO

@typing.final
class TimeseriesBuckets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REQUESTID_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    requestId: builtins.str

    @property
    def bucket(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TimeseriesBucket]:
        ...

    def __init__(self, *, requestId: builtins.str=..., bucket: collections.abc.Iterable[global___TimeseriesBucket] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['bucket', b'bucket', 'requestId', b'requestId']) -> None:
        ...
global___TimeseriesBuckets = TimeseriesBuckets

@typing.final
class TimeseriesBucket(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INDEX_FIELD_NUMBER: builtins.int
    FROMX_FIELD_NUMBER: builtins.int
    TOX_FIELD_NUMBER: builtins.int
    FIRST_FIELD_NUMBER: builtins.int
    LAST_FIELD_NUMBER: builtins.int
    LOCALMIN_FIELD_NUMBER: builtins.int
    LOCALMAX_FIELD_NUMBER: builtins.int
    FINITEPOINTCOUNT_FIELD_NUMBER: builtins.int
    NANCOUNT_FIELD_NUMBER: builtins.int
    POSITIVEINFCOUNT_FIELD_NUMBER: builtins.int
    NEGATIVEINFCOUNT_FIELD_NUMBER: builtins.int
    LOCALSUM_FIELD_NUMBER: builtins.int
    index: builtins.int
    fromX: builtins.float
    toX: builtins.float
    localMin: builtins.float
    localMax: builtins.float
    finitePointCount: builtins.int
    nanCount: builtins.int
    positiveInfCount: builtins.int
    negativeInfCount: builtins.int
    localSum: builtins.float

    @property
    def first(self) -> global___FinitePoint:
        ...

    @property
    def last(self) -> global___FinitePoint:
        ...

    def __init__(self, *, index: builtins.int=..., fromX: builtins.float=..., toX: builtins.float=..., first: global___FinitePoint | None=..., last: global___FinitePoint | None=..., localMin: builtins.float | None=..., localMax: builtins.float | None=..., finitePointCount: builtins.int=..., nanCount: builtins.int=..., positiveInfCount: builtins.int=..., negativeInfCount: builtins.int=..., localSum: builtins.float | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_first', b'_first', '_last', b'_last', '_localMax', b'_localMax', '_localMin', b'_localMin', '_localSum', b'_localSum', 'first', b'first', 'last', b'last', 'localMax', b'localMax', 'localMin', b'localMin', 'localSum', b'localSum']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_first', b'_first', '_last', b'_last', '_localMax', b'_localMax', '_localMin', b'_localMin', '_localSum', b'_localSum', 'finitePointCount', b'finitePointCount', 'first', b'first', 'fromX', b'fromX', 'index', b'index', 'last', b'last', 'localMax', b'localMax', 'localMin', b'localMin', 'localSum', b'localSum', 'nanCount', b'nanCount', 'negativeInfCount', b'negativeInfCount', 'positiveInfCount', b'positiveInfCount', 'toX', b'toX']) -> None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_first', b'_first']) -> typing.Literal['first'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_last', b'_last']) -> typing.Literal['last'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_localMax', b'_localMax']) -> typing.Literal['localMax'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_localMin', b'_localMin']) -> typing.Literal['localMin'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_localSum', b'_localSum']) -> typing.Literal['localSum'] | None:
        ...
global___TimeseriesBucket = TimeseriesBucket

@typing.final
class FinitePoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    X_FIELD_NUMBER: builtins.int
    Y_FIELD_NUMBER: builtins.int
    x: builtins.float
    y: builtins.float

    def __init__(self, *, x: builtins.float=..., y: builtins.float=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['x', b'x', 'y', b'y']) -> None:
        ...
global___FinitePoint = FinitePoint